/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_ACCOUNT_H
#define PVE_SPICE_CLIENT_ACCOUNT_H

#include "proxmox-server.h"
#include "vm-launcher.h"
#include "config.h"

#ifdef USE_PASSWORD_STORAGE
#include "keychain.h"
#endif

namespace PVE {

class Account : public QObject
{
    Q_OBJECT
public:
    Account( const QString& name,
             const QString& user,
             const QString& realm,
             const QString& password,
             const QSharedPointer<Server>& server,
             const QVector<QSharedPointer<VMLauncher>>& launchers =
                            QVector<QSharedPointer<VMLauncher>>() );

    inline QString name() const;
    inline QString user() const;
    inline QString realm() const;
    inline QString password() const;
    inline QSharedPointer<Server> server() const;
    inline const QVector<QSharedPointer<VMLauncher>>& launchers() const;
    inline QSharedPointer<VMLauncher> lastLauncher() const;

    void setName( const QString& name );
    void setUser( const QString& user );
    void setRealm( const QString& realm );
    void setPassword( const QString& password );
    void setServer( const QSharedPointer<Server>& server );
    void setLastLauncher( const QSharedPointer<VMLauncher>& launcher );

    void addLauncher( const QSharedPointer<VMLauncher>& launcher );
    void removeLauncher( const QSharedPointer<VMLauncher>& launcher );

signals:
    void changed( Account* account );

private slots:
    void onServerChanged( Server* server );

private:
    QString _name;
    QString _user;
    QString _realm;
    QString _password;
    QSharedPointer<Server> _server;
    QSharedPointer<VMLauncher> _lastLauncher;
    QVector<QSharedPointer<VMLauncher>> _launchers;
#ifdef USE_PASSWORD_STORAGE
    void updateKeychain();
#endif
};

inline QString Account::name() const
{
    return _name;
}

inline QString Account::user() const
{
    return _user;
}

inline QString Account::realm() const
{
    return _realm;
}

inline QString Account::password() const
{
    return _password;
}

inline QSharedPointer<Server> Account::server() const
{
    return _server;
}

inline const QVector<QSharedPointer<VMLauncher>>& Account::launchers() const
{
    return _launchers;
}

inline QSharedPointer<VMLauncher> Account::lastLauncher() const
{
    return _lastLauncher;
}

} // namespace PVE

#endif // PVE_SPICE_CLIENT_ACCOUNT_H
