/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_CONNECT_COMMAND_H
#define PVE_SPICE_CLIENT_CONNECT_COMMAND_H

#include <QSharedPointer>

#include "command.h"
#include "account.h"
#include "proxmox-node.h"
#include "proxmox-virtual-machine.h"
#include "find-vm-command.h"

namespace PVE {

class ConnectCommand : public Command
{
    Q_OBJECT
public:
    ConnectCommand( QSharedPointer<Account> account,
                    int vmid,
                    bool fullscreen,
                    QObject* parent = Q_NULLPTR );
    void run() Q_DECL_OVERRIDE;

private slots:
    void onFindVMSucceeded();
    void onVMStatusFetched( VirtualMachine::Status status );
    void onSpiceProxyFetched( const QString& spiceProxyFilePath );
    void onVMStatusSet();

private:
    QSharedPointer<Account> _account;
    bool _fullscreen;
    QSharedPointer<VirtualMachine> _virtualMachine;
    int _virtualMachineStartCounter;
    FindVMCommand _findVMCommand;

    void checkVirtualMachineStatus();
};

} // namespace PVE

#endif // PVE_SPICE_CLIENT_CONNECT_COMMAND_H
