/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_FIND_VM_COMMAND_H
#define PVE_SPICE_CLIENT_FIND_VM_COMMAND_H

#include <QSharedPointer>

#include "command.h"
#include "account.h"
#include "proxmox-node.h"
#include "proxmox-virtual-machine.h"

namespace PVE {

class FindVMCommand : public Command
{
    Q_OBJECT
public:
    FindVMCommand( QSharedPointer<Account> account,
                   int vmid,
                   QObject* parent = Q_NULLPTR );
    void run() Q_DECL_OVERRIDE;

    inline QSharedPointer<VirtualMachine> result() const;

private slots:
    void onLoginSucceeded();
    void onNodesFetched( const QVector<QSharedPointer<Node>>& nodes );
    void onVirtualMachinesFetched( const QVector<QSharedPointer<VirtualMachine>>& vms );

private:
    QSharedPointer<Account> _account;
    QSharedPointer<VirtualMachine> _result;
    int _vmid;
    int _searchedNodesCounter;
};

inline QSharedPointer<VirtualMachine> FindVMCommand::result() const
{
    return _result;
}

} // namespace PVE

#endif // PVE_SPICE_CLIENT_FIND_VM_COMMAND_H
