/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_ERRORS_H
#define PVE_SPICE_CLIENT_ERRORS_H

#include <stdexcept>

#include <QString>

namespace PVE {

class NetworkException : public std::runtime_error
{
public:
    explicit NetworkException( const QString& reason )
        : std::runtime_error( "Network error: " + reason.toStdString() )
    {
    }
};

class JsonParsingException : public std::runtime_error
{
public:
    explicit JsonParsingException( const QString& reason )
        : std::runtime_error( "Json parsing error: " + reason.toStdString() )
    {
    }
};

class TokenParsingException : public JsonParsingException
{
public:
    explicit TokenParsingException( const QString& reason )
        : JsonParsingException( "Auth token parsing error: " + reason )
    {
    }
};

class VirtualMachineParsingException : public JsonParsingException
{
public:
    explicit VirtualMachineParsingException( const QString& reason )
        : JsonParsingException( "Virtual machines parsing error: " + reason )
    {
    }
};

class NodesParsingException : public JsonParsingException
{
public:
    explicit NodesParsingException( const QString& reason )
        : JsonParsingException( "Nodes parsing error: " + reason )
    {
    }
};

class DataEntryParsingException : public JsonParsingException
{
public:
    explicit DataEntryParsingException( const QString& reason )
        : JsonParsingException( "Data entry parsing error: " + reason )
    {
    }
};

class DomainParsingException : public JsonParsingException
{
public:
    explicit DomainParsingException( const QString& reason )
        : JsonParsingException( "Domain entry parsing error: " + reason )
    {
    }
};

class ProxmoxClientException : public std::runtime_error
{
public:
    explicit ProxmoxClientException( const QString& reason )
        : std::runtime_error( "Proxmox client error: " + reason.toStdString() )
    {
    }
};

class SpiceRemoteViewerException : public std::runtime_error
{
public:
    explicit SpiceRemoteViewerException( const QString& reason )
        : std::runtime_error( "Spice remote viewer error: " + reason.toStdString() )
    {
    }
};

class NodeException : public std::runtime_error
{
public:
    explicit NodeException( const QString& reason )
        : std::runtime_error( "Node error: " + reason.toStdString() )
    {
    }
};

class SettingsManagerException : public std::runtime_error
{
public:
    explicit SettingsManagerException( const QString& reason )
        : std::runtime_error( "Settings manager error: " + reason.toStdString() )
    {
    }
};

class CaseNotFoundException : public std::runtime_error
{
public:
    explicit CaseNotFoundException( const QString& reason )
        : std::runtime_error( "Case not found: " + reason.toStdString() )
    {
    }
};


class KeychainException : public std::runtime_error
{
public:
    explicit KeychainException( const QString& reason )
        : std::runtime_error( "Keychain error: " + reason.toStdString() )
    {
    }
};

class ArgumentNotFound : public std::invalid_argument
{
public:
    explicit ArgumentNotFound( const QString& reason )
        : std::invalid_argument( "Argument not found: " + reason.toStdString() )
    {
    }
};

} // namespace PVE

#endif // PVE_SPICE_CLIENT_ERRORS_H
