/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_ACCOUNT_DIALOG_CONTROLLER_H
#define PVE_SPICE_CLIENT_ACCOUNT_DIALOG_CONTROLLER_H

#include <QPointer>

#include "account-dialog.h"
#include "account.h"

namespace PVE {

class AccountDialogController : public QObject
{
    Q_OBJECT
public:
    AccountDialogController( QObject* parent = Q_NULLPTR );

    void showDialog( const QString& title,
                     const QString& accountName = QString(),
                     const QString& url = QString(),
                     const QString& userName = QString(),
                     const QString& password = QString(),
                     const QString& realm = QString(),
                     bool ignoreSslErrors = false );
signals:
    void accepted( const QString& accountName,
                   const QString& url,
                   const QString& userName,
                   const QString& password,
                   const QString& realm,
                   bool ignoreSslErrors );
    void canceled();

    void errorOccurred( const QString& reason );

private slots:
    void onCheckRequested( const QString& url,
                           const QString& userName,
                           const QString& password,
                           const QString& realm,
                           bool ignoreSslErrors );

    void onStatusFetchSucceeded( Server::Status status );
    void onStatusFetchFailed( const QString& reason );

    void onDomainsFetchSucceeded( const QVector<QSharedPointer<Domain>>& domains );
    void onDomainsFetchFailed( const QString& reason );

    void onLoginSucceeded();
    void onLoginFailed( const QString& reason );

private:
    QPointer<AccountDialog> _dialog;

    QString _userName;
    QString _password;
    QString _realm;
};

} // namespace PVE

#endif // PVE_SPICE_CLIENT_ACCOUNT_DIALOG_CONTROLLER_H
