/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_ACCOUNT_DIALOG_VIEW_H
#define PVE_SPICE_CLIENT_ACCOUNT_DIALOG_VIEW_H

#include <QLineEdit>
#include <QComboBox>
#include <QCheckBox>
#include <QProgressBar>

namespace PVE {

class AccountDialogView : public QWidget
{
    Q_OBJECT
public:
    AccountDialogView( QWidget* parent = Q_NULLPTR,
                      Qt::WindowFlags flags = Qt::WindowFlags() );

    inline QString accountName() const;
    inline void setAccountName( const QString& accountName );

    inline QString url() const;
    inline void setUrl( const QString& url );
    void setUrlStatus( bool isValid );

    inline QString userName() const;
    inline void setUserName( const QString& userName );
    void setUserNameStatus( bool isValid );

    inline QString password() const;
    inline void setPassword( const QString& password );
    void setPasswordStatus( bool isValid );

    inline QString realm() const;
    inline void setRealm( const QString& realm );
    inline void setAvailableRealms( const QStringList& realms );
    void setRealmStatus( bool isValid );

    inline bool ignoreSslErrors() const;
    inline void setIgnoreSslErrors( bool ignore );

    inline void setBusy( bool isBusy );

signals:
    void okButtonClicked();
    void cancelButtonClicked();
    void checkButtonClicked();

private:
    QLineEdit* _serverNameLineEdit;
    QLineEdit* _urlLineEdit;
    QLineEdit* _userNameLineEdit;
    QLineEdit* _passwordLineEdit;
    QComboBox* _realmComboBox;
    QCheckBox* _ignoreSslErrorsCheckBox;
    QProgressBar* _progressBar;
};

inline QString AccountDialogView::accountName() const
{
    return _serverNameLineEdit->text();
}

inline void AccountDialogView::setAccountName( const QString& serverName )
{
    _serverNameLineEdit->setText( serverName );
}

inline QString AccountDialogView::url() const
{
    return _urlLineEdit->text();
}

inline void AccountDialogView::setUrl( const QString& host )
{
    _urlLineEdit->setText( host );
}

inline QString AccountDialogView::userName() const
{
    return _userNameLineEdit->text();
}

inline void AccountDialogView::setUserName( const QString& userName )
{
    _userNameLineEdit->setText( userName );
}

inline QString AccountDialogView::password() const
{
    return _passwordLineEdit->text();
}

inline void AccountDialogView::setPassword( const QString& password )
{
    _passwordLineEdit->setText( password );
}

inline QString AccountDialogView::realm() const
{
    return _realmComboBox->currentText();
}

inline void AccountDialogView::setRealm( const QString& realm )
{
    _realmComboBox->setCurrentText( realm );
}

inline void AccountDialogView::setAvailableRealms( const QStringList& realms )
{
    _realmComboBox->clear();
    _realmComboBox->addItems( realms );
}

inline bool AccountDialogView::ignoreSslErrors() const
{
    return _ignoreSslErrorsCheckBox->isChecked();
}

inline void AccountDialogView::setIgnoreSslErrors( bool ignore )
{
    _ignoreSslErrorsCheckBox->setChecked( ignore );
}

inline void AccountDialogView::setBusy( bool isBusy )
{
    _progressBar->setVisible( isBusy );
    _serverNameLineEdit->setDisabled( isBusy );
    _urlLineEdit->setDisabled( isBusy );
    _userNameLineEdit->setDisabled( isBusy );
    _passwordLineEdit->setDisabled( isBusy );
    _realmComboBox->setDisabled( isBusy );
}

} // namespace PVE

#endif // PVE_SPICE_CLIENT_ACCOUNT_DIALOG_VIEW_H
