/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_ACCOUNT_DIALOG_H
#define PVE_SPICE_CLIENT_ACCOUNT_DIALOG_H

#include <QDialog>

#include "account-dialog-view.h"

namespace PVE {

class AccountDialog : public QDialog
{
    Q_OBJECT
public:
    AccountDialog( QWidget* parent = Q_NULLPTR,
                   Qt::WindowFlags flags = Qt::WindowFlags() );

    inline void setAccountName( const QString& accountName );
    inline void setUserName( const QString& userName );
    inline void setUserNameStatus( bool isValid );

    inline void setUrl( const QString& url );
    inline void setUrlStatus( bool isValid );

    inline void setPassword( const QString& password );
    inline void setPasswordStatus( bool isValid );

    inline void setRealm( const QString& realm );
    inline void setRealmStatus( bool isValid );

    inline void setIngnoreSslErrors( bool flag );
    inline void setRealms( const QStringList& realms );
    inline void setBusy( bool isBusy );    

signals:
    void accepted( const QString& accountName,
                   const QString& url,
                   const QString& userName,
                   const QString& password,
                   const QString& realm,
                   bool ignoreSslErrors );

    void checkRequested( const QString& host,
                         const QString& userName,
                         const QString& password,
                         const QString& realm,
                         bool ignoreSslErrors );
private slots:
    void onOkButtonClicked();
    void onCancelButtonClicked();
    void onCheckButtonClicked();

private:
    AccountDialogView* _view;
};

inline void AccountDialog::setAccountName( const QString& accountName )
{
    _view->setAccountName( accountName );
}

inline void AccountDialog::setUserName( const QString& userName )
{
    _view->setUserName( userName );
}

inline void AccountDialog::setUserNameStatus( bool isValid )
{
    _view->setUserNameStatus( isValid );
}

inline void AccountDialog::setUrl( const QString& url )
{
    _view->setUrl( url );
}

inline void AccountDialog::setUrlStatus( bool isValid )
{
    _view->setUrlStatus( isValid );
}

inline void AccountDialog::setPassword( const QString& password )
{
    _view->setPassword( password );
}

inline void AccountDialog::setPasswordStatus( bool isValid )
{
    _view->setPasswordStatus( isValid );
}

inline void AccountDialog::setRealm( const QString& realm )
{
    _view->setRealm( realm );
}

inline void AccountDialog::setRealmStatus( bool isValid )
{
    _view->setRealmStatus( isValid );
}

inline void AccountDialog::setIngnoreSslErrors( bool flag )
{
    _view->setIgnoreSslErrors( flag );
}

inline void AccountDialog::setRealms( const QStringList& realms )
{
    _view->setAvailableRealms( realms );
}

inline void AccountDialog::setBusy( bool isBusy )
{
    _view->setBusy( isBusy );
}

} // namespace PVE

#endif // PVE_SPICE_CLIENT_ACCOUNT_DIALOG_H
