/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_ACCOUNTS_TABLE_MODEL_H
#define PVE_SPICE_CLIENT_ACCOUNTS_TABLE_MODEL_H

#include <QAbstractTableModel>

#include "account.h"
#include "settings-manager.h"

namespace PVE {

class AccountsTableModel : public QAbstractTableModel
{
    Q_OBJECT
public:
    AccountsTableModel( QObject* parent = Q_NULLPTR );

    void addAccount( const QSharedPointer<Account>& account );
    void removeAccount( const QSharedPointer<Account>& account );

    inline const QVector<QSharedPointer<Account>>& accounts() const;

    int rowCount( const QModelIndex& index ) const Q_DECL_OVERRIDE;
    int columnCount( const QModelIndex& index ) const Q_DECL_OVERRIDE;
    QVariant data( const QModelIndex& index, int role ) const Q_DECL_OVERRIDE;
    QVariant headerData( int section,
                         Qt::Orientation orientation,
                         int role ) const Q_DECL_OVERRIDE;
private slots:
    void onAccountChanged( Account* account );
};

inline const QVector<QSharedPointer<Account>>& AccountsTableModel::accounts() const
{
    return SettingsManager::get().accounts();
}

} // namespace PVE

#endif // PVE_SPICE_CLIENT_ACCOUNTS_TABLE_MODEL_H
