/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_ACCOUNTS_VIEW_CONTROLLER_H
#define PVE_SPICE_CLIENT_ACCOUNTS_VIEW_CONTROLLER_H

#include <QSharedPointer>
#include <QPointer>
#include <QTimer>

#include "accounts-view.h"
#include "accounts-table-model.h"
#include "account-dialog-controller.h"

namespace PVE {

class AccountsViewController : public QObject
{
    Q_OBJECT
public:
    AccountsViewController();

    void setView( AccountsView* view );

signals:
    void accountSwitched( const QSharedPointer<Account>& account );
    void errorOccurred( const QString& reason );

private slots:
    void onAddButtonClicked();
    void onEditButtonClicked();
    void onRemoveButtonClicked();
    void onAccountSelected( int index );

    void onAddAccepted( const QString& accountName,
                        const QString& host,
                        const QString& userName,
                        const QString& password,
                        const QString& realm,
                        bool ignoreSslErrors );
    void onAddCanceled();

    void onEditAccepted( const QString& accountName,
                         const QString& host,
                         const QString& userName,
                         const QString& password,
                         const QString& realm,
                         bool ignoreSslErrors );
    void onEditCanceled();

    void onPasswordRequestAccepted( const QString& accountName,
                                    const QString& host,
                                    const QString& userName,
                                    const QString& password,
                                    const QString& realm,
                                    bool ignoreSslErrors );
    void onPasswordRequestCanceled();

    void onTimeout();

private:
    AccountsView* _view;
    AccountsTableModel _model;
    AccountDialogController _dialogController;
    int _selectedAccountIndex;
    QTimer _timer;

    void bindAddDialog( AccountDialogController* dialogController );
    void bindEditDialog( AccountDialogController* dialogController );
    void bindPasswordRequestDialog( AccountDialogController* dialogController );

    void unbindAddDialog( AccountDialogController* dialogController );
    void unbindEditDialog( AccountDialogController* dialogController );
    void unbindPasswordRequestDialog( AccountDialogController* dialogController );

    void showInfo( const QString& info );

    QSharedPointer<Account> currentAccount();
};

} // namespace PVE

#endif // PVE_SPICE_CLIENT_ACCOUNTS_VIEW_CONTROLLER_H
