/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_ACCOUNTS_VIEW_H
#define PVE_SPICE_CLIENT_ACCOUNTS_VIEW_H

#include <QTableView>
#include <QItemSelectionModel>

#include "accounts-table-model.h"

namespace PVE {

class AccountsView : public QWidget
{
    Q_OBJECT
public:
    AccountsView( QWidget* parent = Q_NULLPTR,
                  Qt::WindowFlags flags = Qt::WindowFlags() );

    inline void select( int index );
    inline void setModel( AccountsTableModel* model );

signals:
    void accountSelectedAtIndex( int index );

    void addButtonClicked();
    void editButtonClicked();
    void removeButtonClicked();

private slots:
    void onSelectionChanged( const QItemSelection& selected,
                             const QItemSelection& deselected );
private:
    QTableView* _tableView;
};

inline void AccountsView::select( int index )
{
    _tableView->selectRow( index );
}

inline void AccountsView::setModel( AccountsTableModel* model )
{
    _tableView->setModel( model );

    connect( _tableView->selectionModel(),
             &QItemSelectionModel::selectionChanged,
             this,
             &AccountsView::onSelectionChanged );
}

} // namespace PVE

#endif // PVE_SPICE_CLIENT_ACCOUNTS_VIEW_H
