/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_MAIN_VIEW_H
#define PVE_SPICE_CLIENT_MAIN_VIEW_H

#include <QMainWindow>
#include <QSystemTrayIcon>

#include "accounts-view.h"
#include "vm-launchers-view.h"
#include "tray-icon-view.h"

namespace PVE {

class MainView : public QMainWindow
{
    Q_OBJECT
public:
    MainView( QWidget* parent = Q_NULLPTR, 
              Qt::WindowFlags flags = Qt::WindowFlags() );

    inline AccountsView* accountsView() const;
    inline VMLaunchersView* launchersView() const;
    inline TrayIconView* trayIconView() const;

    void reportError( const QString& reason );

    void closeEvent( QCloseEvent* event ) Q_DECL_OVERRIDE;

private:
    AccountsView* _accountsView;
    VMLaunchersView* _launchersView;
    TrayIconView* _trayIconView;
};

inline AccountsView* MainView::accountsView() const
{
    return _accountsView;
}

inline VMLaunchersView* MainView::launchersView() const
{
    return _launchersView;
}

inline TrayIconView* MainView::trayIconView() const
{
    return _trayIconView;
}

} // namespace PVE

#endif // PVE_SPICE_CLIENT_MAIN_VIEW_H

