/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_VM_LAUNCHER_DIALOG_CONTROLLER_H
#define PVE_SPICE_CLIENT_VM_LAUNCHER_DIALOG_CONTROLLER_H

#include <QPointer>

#include "vm-launcher-dialog.h"
#include "vm-launcher.h"
#include "account.h"

namespace PVE {

class VMLauncherDialogController : public QObject
{
    Q_OBJECT
public:
    VMLauncherDialogController( const QSharedPointer<Account> account,
                                QObject* parent = Q_NULLPTR );

    void showDialog( const QString& title,
                     const QString& launcherName = QString(),
                     const QString& vmid = QString(),
                     const VMLaunchArguments& arguments = { false } );
signals:
    void accepted( const QString& launcherName,
                   int vmid,
                   bool fullscreen );
    void canceled();

    void errorOccurred( const QString& reason );

private slots:
    void onCheckRequested( const QString& launcherName, int vmid );
    void onSearchSucceeded();
    void onSearchFailed( const QString& reason );

private:
    QSharedPointer<Account> _account;
    QPointer<VMLauncherDialog> _dialog;
    QString _newLauncherName;
};

} // namespace PVE

#endif // PVE_SPICE_CLIENT_VM_LAUNCHER_DIALOG_CONTROLLER_H
