/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_VM_LAUNCHER_DIALOG_VIEW_H
#define PVE_SPICE_CLIENT_VM_LAUNCHER_DIALOG_VIEW_H

#include <QLineEdit>
#include <QCheckBox>
#include <QProgressBar>

namespace PVE {

class VMLauncherDialogView : public QWidget
{
    Q_OBJECT
public:
    VMLauncherDialogView( QWidget* parent = Q_NULLPTR,
                          Qt::WindowFlags flags = Qt::WindowFlags() );

    inline QString launcherName() const;
    inline void setLauncherName( const QString& launcherName );

    inline QString vmid() const;
    inline void setVmid( const QString& vmid );
    void setVmidStatus( bool isValid );

    inline bool fullscreen() const;
    inline void setFullscreen( bool flag );

    inline void setBusy( bool isBusy );

signals:
    void okButtonClicked();
    void cancelButtonClicked();
    void checkButtonClicked();

private:
    QLineEdit* _launcherNameLineEdit;
    QLineEdit* _vmidLineEdit;
    QCheckBox* _fullscreenCheckBox;
    QProgressBar* _progressBar;
};

inline QString VMLauncherDialogView::launcherName() const
{
    return _launcherNameLineEdit->text();
}

inline void VMLauncherDialogView::setLauncherName( const QString& launcherName )
{
    _launcherNameLineEdit->setText( launcherName );
}

inline QString VMLauncherDialogView::vmid() const
{
    return _vmidLineEdit->text();
}

inline void VMLauncherDialogView::setVmid( const QString& vmid )
{
    _vmidLineEdit->setText( vmid );
}

inline bool VMLauncherDialogView::fullscreen() const
{
    return _fullscreenCheckBox->isChecked();
}

inline void VMLauncherDialogView::setFullscreen( bool flag )
{
    _fullscreenCheckBox->setChecked( flag );
}

inline void VMLauncherDialogView::setBusy( bool isBusy )
{
    _progressBar->setVisible( isBusy );
    _launcherNameLineEdit->setDisabled( isBusy );
    _vmidLineEdit->setDisabled( isBusy );
    _fullscreenCheckBox->setDisabled( isBusy );
}

} // namespace PVE

#endif // PVE_SPICE_CLIENT_VM_LAUNCHER_DIALOG_VIEW_H
