/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_VM_LAUNCHER_DIALOG_H
#define PVE_SPICE_CLIENT_VM_LAUNCHER_DIALOG_H

#include <QDialog>

#include "vm-launcher-dialog-view.h"

namespace PVE {

class VMLauncherDialog : public QDialog
{
    Q_OBJECT
public:
    VMLauncherDialog( QWidget* parent = Q_NULLPTR,
                      Qt::WindowFlags flags = Qt::WindowFlags() );

    inline void setLauncherName( const QString& launcherName );
    inline void setVmid( const QString& vmid );
    inline void setVmidStatus( bool isValid );
    inline void setFullscreen( bool flag );
    inline void setBusy( bool isBusy );

signals:
    void accepted( const QString& launcherName,
                   int vmid,
                   bool fullscreen );

    void checkRequested( const QString& launcherName, int vmid );

private slots:
    void onOkButtonClicked();
    void onCancelButtonClicked();
    void onCheckButtonClicked();

private:
    VMLauncherDialogView* _view;
};

inline void VMLauncherDialog::setLauncherName( const QString& launcherName )
{
    _view->setLauncherName( launcherName );
}

inline void VMLauncherDialog::setVmid( const QString& vmid )
{
    _view->setVmid( vmid );
}

inline void VMLauncherDialog::setVmidStatus( bool isValid )
{
    _view->setVmidStatus( isValid );
}

inline void VMLauncherDialog::setFullscreen( bool flag )
{
    _view->setFullscreen( flag );
}

inline void VMLauncherDialog::setBusy( bool isBusy )
{
    _view->setBusy( isBusy );
}

} // namespace PVE

#endif // PVE_SPICE_CLIENT_VM_LAUNCHER_DIALOG_H
