/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_VM_LAUNCHERS_TABLE_MODEL_H
#define PVE_SPICE_CLIENT_VM_LAUNCHERS_TABLE_MODEL_H

#include <QSharedPointer>
#include <QAbstractTableModel>

#include "vm-launcher.h"
#include "account.h"

namespace PVE {

class VMLaunchersTableModel : public QAbstractTableModel
{
    Q_OBJECT
public:
    VMLaunchersTableModel( const QSharedPointer<Account>& account,
                           QObject* parent = Q_NULLPTR );

    void addVMLauncher( const QSharedPointer<VMLauncher>& launcher );
    void removeVMLauncher( const QSharedPointer<VMLauncher>& launcher );

    inline const QVector<QSharedPointer<VMLauncher>>& launchers() const;
    inline QSharedPointer<VMLauncher> lastLauncher() const;
    inline void setLastLauncher( const QSharedPointer<VMLauncher>& launcher );

    int rowCount( const QModelIndex& index ) const Q_DECL_OVERRIDE;
    int columnCount( const QModelIndex& index ) const Q_DECL_OVERRIDE;
    QVariant data( const QModelIndex& index, int role ) const Q_DECL_OVERRIDE;
    QVariant headerData( int section,
                         Qt::Orientation orientation,
                         int role ) const Q_DECL_OVERRIDE;
private slots:
    void onLauncherChanged( VMLauncher* launcher );

private:
    QSharedPointer<Account> _account;
};

inline const QVector<QSharedPointer<VMLauncher>>& VMLaunchersTableModel::launchers() const
{
    return _account->launchers();
}

inline QSharedPointer<VMLauncher> VMLaunchersTableModel::lastLauncher() const
{
    return _account->lastLauncher();
}

inline void VMLaunchersTableModel::setLastLauncher( const QSharedPointer<VMLauncher>& launcher )
{
    _account->setLastLauncher( launcher );
}

} // namespace PVE

#endif // PVE_SPICE_CLIENT_VM_LAUNCHERS_TABLE_MODEL_H
