/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_VM_LAUNCHERS_VIEW_CONTROLLER_H
#define PVE_SPICE_CLIENT_VM_LAUNCHERS_VIEW_CONTROLLER_H

#include <QSharedPointer>
#include <QPointer>

#include "vm-launchers-view.h"
#include "vm-launchers-table-model.h"
#include "account.h"
#include "vm-launcher-validator.h"
#include "vm-launcher-connector.h"
#include "vm-launcher-appender.h"
#include "vm-launcher-dialog-controller.h"

namespace PVE {

class VMLaunchersViewController : public QObject
{
    Q_OBJECT
public:
    VMLaunchersViewController();

    void setView( VMLaunchersView* view );
    void setAccount( const QSharedPointer<Account>& account );

signals:
    void errorOccurred( const QString& reason );

private slots:
    void onAddButtonClicked();
    void onEditButtonClicked();
    void onRemoveButtonClicked();
    void onConnectButtonClicked();
    void onLauncherSelected( int index );

    void onAddAccepted( const QString& launcherName,
                        int vmid,
                        bool fullscreen );
    void onAddCanceled();

    void onEditAccepted( const QString& launcherName,
                         int vmid,
                         bool fullscreen );
    void onEditCanceled();

    void onTimeout();

    void onConnected();
    void onAppended( const QSharedPointer<VMLauncher>& launcher );

    void onErrorOccurred( const QString& reason );

private:
    VMLaunchersView* _view;
    int _selectedLauncherIndex;
    QTimer _timer;

    QPointer<VMLaunchersTableModel> _model;
    QPointer<VMLauncherDialogController> _dialogController;
    QPointer<VMLauncherConnector> _launcherConnector;
    QPointer<VMLauncherValidator> _launcherValidator;
    QPointer<VMLauncherAppender> _launcherAppender;

    void bind( VMLauncherConnector* connector );
    void bind( VMLauncherValidator* validator );
    void bind( VMLauncherAppender* appender );

    void bindAddDialog( VMLauncherDialogController* dialogController );
    void bindEditDialog( VMLauncherDialogController* dialogController );
    void unbindAddDialog( VMLauncherDialogController* dialogController );
    void unbindEditDialog( VMLauncherDialogController* dialogController );

    void showInfo( const QString& info );

    QSharedPointer<VMLauncher> currentLauncher();
};

} // namespace PVE

#endif // PVE_SPICE_CLIENT_VM_LAUNCHERS_VIEW_CONTROLLER_H
