/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_VM_LAUNCHERS_VIEW_H
#define PVE_SPICE_CLIENT_VM_LAUNCHERS_VIEW_H

#include <QTableView>
#include <QProgressBar>

#include "vm-launchers-table-model.h"

namespace PVE {

class VMLaunchersView : public QWidget
{
    Q_OBJECT
public:
    VMLaunchersView( QWidget* parent = Q_NULLPTR,
                     Qt::WindowFlags flags = Qt::WindowFlags() );

    inline void select( int index );
    inline void setModel( VMLaunchersTableModel* model );
    inline void setBusy( bool isBusy );

signals:
    void launcherSelectedAtIndex( int index );

    void addButtonClicked();
    void editButtonClicked();
    void removeButtonClicked();
    void connectButtonClicked();

private slots:
    void onTableActivated( const QModelIndex& index );

private:
    QTableView* _tableView;
    QProgressBar* _progressBar;
};

inline void VMLaunchersView::select( int index )
{
    _tableView->selectRow( index );
}

inline void VMLaunchersView::setModel( VMLaunchersTableModel* model )
{
    _tableView->setModel( model );
}

inline void VMLaunchersView::setBusy( bool isBusy )
{
    _progressBar->setVisible( isBusy );
}

} // namespace PVE

#endif // PVE_SPICE_CLIENT_VM_LAUNCHERS_VIEW_H
