/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_PROXMOX_DOMAIN_H
#define PVE_SPICE_CLIENT_PROXMOX_DOMAIN_H

#include <QString>

namespace PVE {

class Domain
{
public:
    enum class Type
    {
        Pve,
        Pam,
        Ldap,
        ActiveDirectory
    };

    Domain( Type type,
            const QString& realm,
            const QString& comment = QString() )
        : _type( type ),
          _realm( realm ),
          _comment( comment )
    {
    }

    inline Type type() const;
    inline QString realm() const;
    inline QString comment() const;

private:
    Type _type;
    QString _realm;
    QString _comment;
};

inline Domain::Type Domain::type() const
{
    return _type;
}

inline QString Domain::realm() const
{
    return _realm;
}

inline QString Domain::comment() const
{
    return _comment;
}

} // namespace PVE

#endif // PVE_SPICE_CLIENT_PROXMOX_DOMAIN_H
