/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_NODE_H
#define PVE_SPICE_CLIENT_NODE_H

#include <QSharedPointer>

#include "proxmox-rest-client.h"
#include "proxmox-virtual-machine.h"

namespace PVE {

class Node : public QObject
{
    Q_OBJECT
public:
    Node( const QSharedPointer<ProxmoxRestClient>& restClient,
          const QString& id );

    void fetchVirtualMachines();

signals:
    void virtualMachinesFetched( const QVector<QSharedPointer<VirtualMachine>>& vms );

    void errorOccurred( const QString& reason );

private slots:
    void onReplyFinished( QNetworkReply* reply );

private:
    QSharedPointer<ProxmoxRestClient> _restClient;
    QString _id;
    QVector<QSharedPointer<VirtualMachine>> _virtualMachines;
    QNetworkReply* _virtualMachinesFetchReply;

    QVector<QSharedPointer<VirtualMachine>>
    processVirtualMachinesFetchReply( QNetworkReply* reply );
};

} // namespace PVE

#endif // PVE_SPICE_CLIENT_NODE_H
