/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_REST_CLIENT_H
#define PVE_SPICE_CLIENT_REST_CLIENT_H

#include <QSharedPointer>

#include <QNetworkAccessManager>
#include <QNetworkReply>

#include "proxmox-user.h"

namespace PVE {

class ProxmoxRestClient : public QObject
{
    Q_OBJECT
public:
    ProxmoxRestClient( const QUrl& baseURL );

    inline void setUser( const QSharedPointer<User>& user );
    inline QUrl url() const;
    inline bool ignoreSslErrors() const;
    inline void setIgnoreSslErrors( bool flag );

    QNetworkReply* get( const QString& endpoint );
    QNetworkReply* post( const QString& endpoint,
                         const QByteArray& data );
signals:
    void finished( QNetworkReply* reply );

private slots:
    void onSslErrors( QNetworkReply* reply,
                      const QList<QSslError>& errors );
private:
    QUrl _baseURL;
    QSharedPointer<User> _user;
    QNetworkAccessManager _networkManager;
    bool _ignoreSslErrors;
};

inline void ProxmoxRestClient::setUser( const QSharedPointer<User>& user )
{
    _user = user;
}

inline QUrl ProxmoxRestClient::url() const
{
    return _baseURL;
}

inline bool ProxmoxRestClient::ignoreSslErrors() const
{
    return _ignoreSslErrors;
}

inline void ProxmoxRestClient::setIgnoreSslErrors( bool flag )
{
    _ignoreSslErrors = flag;
}

} // namespace PVE

#endif // PVE_SPICE_CLIENT_REST_CLIENT_H
