/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_VIRTUAL_MACHINE_H
#define PVE_SPICE_CLIENT_VIRTUAL_MACHINE_H

#include <QSharedPointer>
#include <QTimer>

#include "proxmox-rest-client.h"

namespace PVE {

class VirtualMachine : public QObject
{
    Q_OBJECT
public:
    enum class Status
    {
        Running,
        Stopped        
    };

    VirtualMachine( const QSharedPointer<ProxmoxRestClient>& restClient,
                    int vmID,
                    const QString& nodeID,
                    const QString& name );
    
    void fetchStatus();
    void fetchSpiceProxy();

    inline int id() const;
    inline QString name() const;
    inline Status status() const;

    void start();

signals:
    void statusFetched( Status status );
    void spiceProxyFetched( const QString& spiceProxyFilePath );
    void statusSet();

    void errorOccurred( const QString& reason );

    void changed( VirtualMachine* virtualMachine );

private slots:
    void onReplyFinished( QNetworkReply* reply );
    void onTimeout();

private:
    QSharedPointer<ProxmoxRestClient> _restClient;
    int _vmID;
    QString _nodeID;
    QString _name;
    Status _status;
    QTimer _timer;

    QNetworkReply* _fetchStatusReply;
    QNetworkReply* _fetchSpiceProxyReply;
    QNetworkReply* _startReply;
};

inline int VirtualMachine::id() const
{
    return _vmID;
}

inline QString VirtualMachine::name() const
{
    return _name;
}

inline VirtualMachine::Status VirtualMachine::status() const
{
    return _status;
}

} // namespace PVE

#endif // PVE_SPICE_CLIENT_VIRTUAL_MACHINE_H

