/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_SETTINGS_MANAGER_H
#define PVE_SPICE_CLIENT_SETTINGS_MANAGER_H

#include "settings.h"

namespace PVE {

class SettingsManager
{
public:
    ~SettingsManager();

    static SettingsManager& get();

    inline int accountsUpdatingInterval() const;
    inline int launchersUpdatingInterval() const;

    QSharedPointer<Account> lastAccount() const;
    void setLastAccount( const QSharedPointer<Account>& account );

    const QVector<QSharedPointer<Account>>& accounts() const;
    void addAccount( const QSharedPointer<Account>& account );
    void removeAccount( const QSharedPointer<Account>& account );

private:
    Settings _settings;

    SettingsManager();
    SettingsManager( const SettingsManager& ) = delete;
};

inline int SettingsManager::accountsUpdatingInterval() const
{
    return _settings.accountsUpdatingInterval;
}

inline int SettingsManager::launchersUpdatingInterval() const
{
    return _settings.launchersUpdatingInterval;
}

} // namespace PVE

#endif // PVE_SPICE_CLIENT_SETTINGS_MANAGER_H

