/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PVE_SPICE_CLIENT_VM_LAUNCHER_H
#define PVE_SPICE_CLIENT_VM_LAUNCHER_H

#include "proxmox-virtual-machine.h"

namespace PVE {

struct VMLaunchArguments
{
    bool fullscreen = false;
};

bool operator ==( const VMLaunchArguments& lhs, const VMLaunchArguments& rhs );
bool operator !=( const VMLaunchArguments& lhs, const VMLaunchArguments& rhs );

class VMLauncher : public QObject
{
    Q_OBJECT
public:
    VMLauncher( const QString& name,
                int vmid,
                const VMLaunchArguments& arguments );

    inline QString name() const;
    inline int vmid() const;
    inline VMLaunchArguments arguments() const;
    inline bool isValid() const;

    inline QSharedPointer<VirtualMachine> cachedVM() const;

    void setName( const QString& name );
    void setVmid( int vmid );
    void setArguments( const VMLaunchArguments& arguments );
    void setCachedVM( const QSharedPointer<VirtualMachine>& vm );

signals:
    void changed( VMLauncher* launcher );

private slots:
    void onCachedVMChanged( VirtualMachine* vm );

private:
    QString _name;
    int _vmid;
    VMLaunchArguments _arguments;
    QSharedPointer<VirtualMachine> _cachedVM;
};

inline QString VMLauncher::name() const
{
    return _name;
}

inline int VMLauncher::vmid() const
{
    return _vmid;
}

inline VMLaunchArguments VMLauncher::arguments() const
{
    return _arguments;
}

inline bool VMLauncher::isValid() const
{
    return _cachedVM != Q_NULLPTR;
}

inline QSharedPointer<VirtualMachine> VMLauncher::cachedVM() const
{
    return _cachedVM;
}

} // namespace PVE

#endif // PVE_SPICE_CLIENT_VM_LAUNCHER_H
