/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "application.h"
#include "config.h"
#include "errors.h"
#include "help-command.h"
#include "version-command.h"

namespace {

const QString kVersionFormat = "%1.%2.%3";

const QString kOrganizationName = "PVE";

const QString kQuotesWarn = "\nPlease, use quotes to pass argument which"
                            "\ncontains special characters or delimeters";
} // namespace

namespace PVE {

Application::Application( QPointer<QCoreApplication> qapp )
    : QObject(),
      _qapp( std::move( qapp ) ),
      _parser()
{
    const auto version = QString( kVersionFormat )
                         .arg( QString::number( VERSION_MAJOR ),
                               QString::number( VERSION_MINOR ),
                               QString::number( VERSION_PATCH ) );
    QCoreApplication::setApplicationVersion( version );
    QCoreApplication::setApplicationName( APPLICATION_NAME );
    QCoreApplication::setOrganizationName( kOrganizationName );
}

int Application::run()
{
    return _qapp->exec();
}

QPointer<Command> Application::processArgs()
{
    _parser.setApplicationDescription( APPLICATION_DESCRIPTION + kQuotesWarn );
    const auto helpOption = _parser.addHelpOption();
    const auto versionOption = _parser.addVersionOption();
    _parser.addOption( QCommandLineOption( { "n", "no-gui" },
                                           "Run application without GUI. "
                                           "Run pve-spice-client --no-gui "
                                           "--help for additional info." ) );

    if( !_parser.parse( _qapp->arguments() ) )
    {
        throw std::invalid_argument( "Could not parse command line arguments" );
    }

    if( _parser.isSet( helpOption ) )
    {
        return new HelpCommand( _parser.helpText() );
    }

    if( _parser.isSet( versionOption ) )
    {
        return new VersionCommand( QCoreApplication::applicationVersion() );
    }

    return Q_NULLPTR;
}

} // namespace PVE
