/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "find-vm-command.h"

#include "proxmox-node.h"

namespace PVE {

FindVMCommand::FindVMCommand( QSharedPointer<Account> account,
                              int vmid,
                              QObject* parent )
    : Command( parent ),
      _account( account ),
      _result(),
      _vmid( vmid ),
      _searchedNodesCounter( 0 )
{
    const auto server = _account->server().data();
    connect( server,
             &Server::loginSucceeded,
             this,
             &FindVMCommand::onLoginSucceeded );

    connect( server,
             &Server::nodesFetched,
             this,
             &FindVMCommand::onNodesFetched );

    connect( server,
             &Server::errorOccurred,
             this,
             &FindVMCommand::failed );
}

void FindVMCommand::run()
{
    const auto user = QString( "%1@%2" ).arg( _account->user() )
                                        .arg( _account->realm() );
    _account->server()->login( user, _account->password() );
}

void FindVMCommand::onLoginSucceeded()
{
    _account->server()->fetchNodes();
}

void FindVMCommand::onNodesFetched( const QVector<QSharedPointer<Node>>& nodes )
{
    for( const auto& node : nodes )
    {
        connect( node.data(),
                 &Node::virtualMachinesFetched,
                 this,
                 &FindVMCommand::onVirtualMachinesFetched );

        connect( node.data(),
                 &Node::errorOccurred,
                 this,
                 &FindVMCommand::failed );

        node->fetchVirtualMachines();

        ++_searchedNodesCounter;
    }
}

void FindVMCommand::onVirtualMachinesFetched( const QVector<QSharedPointer<VirtualMachine>>& vms )
{
    --_searchedNodesCounter;

    for( const auto& vm : vms )
    {
        if( vm->id() == _vmid )
        {
            _result = vm;

            emit succeeded();

            return;
        }
    }

    if( !_searchedNodesCounter && !_result )
    {
        emit succeeded();
    }
}

} // namespace PVE
