/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "get-realms-command.h"

namespace PVE {

GetRealmsCommand::GetRealmsCommand( QSharedPointer<Account> account,
                                    QObject* parent )
    : Command( parent ),
      _account( account ),
      _result()
{
    const auto server = _account->server().data();

    connect( server,
             &Server::domainsFetched,
             this,
             &GetRealmsCommand::onDomainsFetched );

    connect( server,
             &Server::errorOccurred,
             this,
             &GetRealmsCommand::failed );
}

void GetRealmsCommand::run()
{
    _account->server()->fetchDomains();
}

void GetRealmsCommand::onDomainsFetched( const QVector<QSharedPointer<Domain>>& domains )
{
    for( const auto& domain : domains )
    {
        _result.push_back( domain->realm() );
    }

    emit succeeded();
}

} // namespace PVE
