#include "global.h"

#include "errors.h"

namespace {

const QString kStatusRunning = "running";
const QString kStatusStopped = "stopped";

const QString kTypePam = "pam";
const QString kTypeLdap = "ldap";
const QString kTypePve = "pve";
const QString kTypeActiveDirectory = "ad";

const QString kUnknownValueFormat = "Unknown value: %1";

} // namespace

namespace PVE {
namespace Converter {

VirtualMachine::Status virtualMachineStatusFromString( const QString& string )
{
    if( string == kStatusRunning )
    {
        return VirtualMachine::Status::Running;
    }
    else if( string == kStatusStopped )
    {
        return VirtualMachine::Status::Stopped;
    }

    throw CaseNotFoundException( QString( kUnknownValueFormat ).arg( string ) );
}

QString virtualMachineStatusToString( VirtualMachine::Status status )
{
    switch( status )
    {
        case VirtualMachine::Status::Stopped: return kStatusStopped;
        case VirtualMachine::Status::Running: return kStatusRunning;

    default:
        throw CaseNotFoundException( QString( kUnknownValueFormat )
                                     .arg( static_cast<int>( status ) ) );
    }
}

Domain::Type domainTypeFromString( const QString& string )
{
    if( string == kTypePam )
    {
        return Domain::Type::Pam;
    }
    else if( string == kTypeLdap )
    {
        return Domain::Type::Ldap;
    }
    else if( string == kTypePve )
    {
        return Domain::Type::Pve;
    }
    else if( string == kTypeActiveDirectory )
    {
        return Domain::Type::ActiveDirectory;
    }

    throw CaseNotFoundException( QString( kUnknownValueFormat ).arg( string ) );
}

} // namespace Converter
} // namespace PVE
