/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "gui-application.h"

#include <QApplication>

namespace PVE {

GuiApplication::GuiApplication( int& argc, char* argv[] )
    : Application( new QApplication( argc, argv ) ),
      _view( QSharedPointer<MainView>::create() ),
      _controller(),
      _command()
{
    _controller.setView( _view );
}

int GuiApplication::run()
{
    _command = processArgs();

    if( _command )
    {
        bind( _command.data() );

        _command->run();
    }

    _view->showMaximized();
    return Application::run();
}

void GuiApplication::reportUnhandledException( const std::exception& exception )
{
    _view->reportError( exception.what() );
}

void GuiApplication::reportError( const QString& reason )
{
    _view->reportError( reason );
}

void GuiApplication::bind( Command* command )
{
    connect( command,
             &Command::succeeded,
             this,
             &GuiApplication::onCommandSucceeded,
             Qt::QueuedConnection );

    connect( command,
             &Command::failed,
             this,
             &GuiApplication::onCommandFailed,
             Qt::QueuedConnection );
}

void GuiApplication::onCommandSucceeded()
{
    _qapp->quit();
}

void GuiApplication::onCommandFailed( const QString& reason )
{
    reportError( reason );
    _qapp->quit();
}

} // namespace PVE
