/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "account-dialog-view.h"

#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QPushButton>

namespace {

const QString kServerNamePlaceholder = "server name";
const QString kHostPlaceholder = "https://hostname:port";
const QString kUserNamePlaceholder = "login";
const QString kPasswordPlaceholder = "password";
const QString kOkButtonLabel = "Ok";
const QString kCancelButtonLabel = "Cancel";
const QString kCheckButtonLabel = "Check";
const QString kIgnoreSslErrorsLabel = "Ignore SSL errors";

const QString kUrlValid = "QLineEdit{background:rgb(60,179,113);}";
const QString kUrlInvalid = "QLineEdit{background:rgb(255,99,71);}";
const QString kUserNameValid = "QLineEdit{background:rgb(60,179,113);}";
const QString kUserNameInvalid = "QLineEdit{background:rgb(255,99,71);}";
const QString kPasswordValid = "QLineEdit{background:rgb(60,179,113);}";
const QString kPasswordInvalid = "QLineEdit{background:rgb(255,99,71);}";
const QString kRealmValid = "QComboBox{background:rgb(60,179,113);}";
const QString kRealmInvalid = "QComboBox{background:rgb(255,99,71);}";

} // namespace

namespace PVE {

AccountDialogView::AccountDialogView( QWidget* parent,
                                    Qt::WindowFlags flags )
    : QWidget( parent, flags ),
      _serverNameLineEdit( new QLineEdit ),
      _urlLineEdit( new QLineEdit ),
      _userNameLineEdit( new QLineEdit ),
      _passwordLineEdit( new QLineEdit ),
      _realmComboBox( new QComboBox ),
      _ignoreSslErrorsCheckBox( new QCheckBox( kIgnoreSslErrorsLabel ) ),
      _progressBar( new QProgressBar )
{
    _serverNameLineEdit->setPlaceholderText( kServerNamePlaceholder );
    _urlLineEdit->setPlaceholderText( kHostPlaceholder );
    _userNameLineEdit->setPlaceholderText( kUserNamePlaceholder );
    _passwordLineEdit->setPlaceholderText( kPasswordPlaceholder );
    _passwordLineEdit->setEchoMode( QLineEdit::EchoMode::Password );
    _realmComboBox->setEditable( true );
    _progressBar->setRange( 0, 0 );
    _progressBar->setVisible( false );

    const auto okButton = new QPushButton( kOkButtonLabel );
    connect( okButton,
             &QPushButton::clicked,
             this,
             &AccountDialogView::okButtonClicked );

    const auto cancelButton = new QPushButton( kCancelButtonLabel );
    connect( cancelButton,
             &QPushButton::clicked,
             this,
             &AccountDialogView::cancelButtonClicked );

    const auto checkButton = new QPushButton( kCheckButtonLabel );
    connect( checkButton,
             &QPushButton::clicked,
             this,
             &AccountDialogView::checkButtonClicked );

    const auto buttonsLayout = new QHBoxLayout;
    buttonsLayout->addWidget( checkButton );
    buttonsLayout->addStretch();
    buttonsLayout->addWidget( okButton );
    buttonsLayout->addWidget( cancelButton );

    const auto layout = new QVBoxLayout;
    layout->addWidget( _serverNameLineEdit );
    layout->addWidget( _urlLineEdit );
    layout->addWidget( _userNameLineEdit );
    layout->addWidget( _passwordLineEdit );
    layout->addWidget( _realmComboBox );
    layout->addWidget( _ignoreSslErrorsCheckBox );
    layout->addWidget( _progressBar );
    layout->addLayout( buttonsLayout );

    setLayout( layout );
}

void AccountDialogView::setUrlStatus( bool isValid )
{
    _urlLineEdit->setStyleSheet( isValid ? kUrlValid : kUrlInvalid );
}

void AccountDialogView::setUserNameStatus( bool isValid )
{
    _userNameLineEdit->setStyleSheet( isValid ? kUserNameValid
                                              : kUserNameInvalid );
}

void AccountDialogView::setPasswordStatus( bool isValid )
{
    _passwordLineEdit->setStyleSheet( isValid ? kPasswordValid
                                              : kPasswordInvalid );
}

void AccountDialogView::setRealmStatus( bool isValid )
{
    _realmComboBox->setStyleSheet( isValid ? kRealmValid : kRealmInvalid );
}

} // namespace PVE
