/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "account-dialog.h"

#include <QVBoxLayout>

namespace PVE {

AccountDialog::AccountDialog( QWidget* parent,
                            Qt::WindowFlags flags )
    : QDialog( parent, flags ),
      _view( new AccountDialogView )
{
    connect( _view,
             &AccountDialogView::okButtonClicked,
             this,
             &AccountDialog::onOkButtonClicked );

    connect( _view,
             &AccountDialogView::cancelButtonClicked,
             this,
             &AccountDialog::onCancelButtonClicked );

    connect( _view,
             &AccountDialogView::checkButtonClicked,
             this,
             &AccountDialog::onCheckButtonClicked );

    const auto layout = new QVBoxLayout;
    layout->addWidget( _view );

    setLayout( layout );
}

void AccountDialog::onOkButtonClicked()
{
    emit accepted( _view->accountName(),
                   _view->url(),
                   _view->userName(),
                   _view->password(),
                   _view->realm(),
                   _view->ignoreSslErrors() );
    accept();
}

void AccountDialog::onCancelButtonClicked()
{
    reject();
}

void AccountDialog::onCheckButtonClicked()
{
    emit checkRequested( _view->url(),
                         _view->userName(),
                         _view->password(),
                         _view->realm(),
                         _view->ignoreSslErrors() );
}

} // namespace PVE
