/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "main-view-controller.h"

namespace PVE {

MainViewController::MainViewController()
    : _accountsViewController(),
      _launchersViewController(),
      _trayIconViewController(),
      _view()
{
    connect( &_accountsViewController,
             &AccountsViewController::accountSwitched,
             this,
             &MainViewController::onAccountSwitched );

    connect( &_accountsViewController,
             &AccountsViewController::errorOccurred,
             this,
             &MainViewController::onErrorOccurred );

    connect( &_launchersViewController,
             &VMLaunchersViewController::errorOccurred,
             this,
             &MainViewController::onErrorOccurred );
}

void MainViewController::setView( const QSharedPointer<MainView>& view )
{
    _view = view;

    if( !_view )
    {
        return;
    }

    _launchersViewController.setView( _view->launchersView() );
    _accountsViewController.setView( _view->accountsView() );
    _trayIconViewController.setView( _view->trayIconView() );
    _trayIconViewController.setMainView( _view.data() );
}

void MainViewController::onAccountSwitched( const QSharedPointer<Account>& account )
{
    _launchersViewController.setAccount( account );
}

void MainViewController::onErrorOccurred( const QString& reason )
{
    _view->reportError( reason );
}

} // namespace PVE
