/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "main-view.h"

#include <QMessageBox>
#include <QCloseEvent>
#include <QHBoxLayout>

#include "config.h"

namespace {

const QString kErrorTitle = "An error occurred!";
const QString kFinishButtonLabel = "Run";
const QString kCancelButtonLabel = "Quit";

const int kMinimumWidth = 480;
const int kMinimumHeight = 320;

} // namespace

namespace PVE {

MainView::MainView( QWidget* parent, Qt::WindowFlags flags )
    : QMainWindow( parent, flags ),
      _accountsView( new AccountsView ),
      _launchersView( new VMLaunchersView ),
      _trayIconView( new TrayIconView )
{
    setMinimumSize( kMinimumWidth, kMinimumHeight );
    setWindowTitle( APPLICATION_NAME );
    setWindowIcon( QIcon::fromTheme( APPLICATION_ICON_NAME,
                                     QIcon::fromTheme( APPLICATION_FALLBACK_ICON_NAME ) ) );

    const auto layout = new QHBoxLayout;
    layout->addWidget( _accountsView );
    layout->addWidget( _launchersView );

    const auto widget = new QWidget;
    widget->setLayout( layout );

    setCentralWidget( widget );
}

void MainView::reportError( const QString& reason )
{
    QMessageBox::critical( this, kErrorTitle, reason );
}

void MainView::closeEvent( QCloseEvent* event )
{
#ifdef Q_OS_OSX
    if( !event->spontaneous() || !isVisible() )
    {
        return;
    }
#endif
    hide();
    event->ignore();
}

} // namespace PVE
