/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "vm-launcher-dialog-controller.h"
#include "find-vm-command.h"

namespace PVE {

VMLauncherDialogController::VMLauncherDialogController( const QSharedPointer<Account> account,
                                                        QObject* parent )
    : QObject( parent ),
      _account( account ),
      _dialog(),
      _newLauncherName()
{
}

void VMLauncherDialogController::showDialog( const QString& title,
                                             const QString& launcherName,
                                             const QString& vmid,
                                             const VMLaunchArguments& arguments )
{
    _dialog = new VMLauncherDialog;

    _dialog->setWindowTitle( title );

    _dialog->setLauncherName( launcherName );
    _dialog->setVmid( vmid );
    _dialog->setFullscreen( arguments.fullscreen );

    connect( _dialog.data(),
             &VMLauncherDialog::accepted,
             this,
             &VMLauncherDialogController::accepted );

    connect( _dialog.data(),
             &VMLauncherDialog::rejected,
             this,
             &VMLauncherDialogController::canceled );

    connect( _dialog.data(),
             &VMLauncherDialog::checkRequested,
             this,
             &VMLauncherDialogController::onCheckRequested );

    _dialog->exec();
}

void VMLauncherDialogController::onCheckRequested( const QString& launcherName,
                                                   int vmid )
{
    _newLauncherName = launcherName;

    const auto findVMCommand = new FindVMCommand( _account, vmid );

    connect( findVMCommand,
             &FindVMCommand::succeeded,
             this,
             &VMLauncherDialogController::onSearchSucceeded );

    connect( findVMCommand,
             &FindVMCommand::failed,
             this,
             &VMLauncherDialogController::onSearchFailed );

    findVMCommand->run();
}

void VMLauncherDialogController::onSearchSucceeded()
{
    const auto command = qobject_cast<FindVMCommand*>( sender() );
    const auto vm = command->result();

    if( vm )
    {
        _dialog->setVmidStatus( true );

        if( _newLauncherName.isEmpty() )
        {
            _dialog->setLauncherName( vm->name() );
        }
    }
    else
    {
        _dialog->setVmidStatus( false );
    }

    _dialog->setBusy( false );

    command->deleteLater();
}

void VMLauncherDialogController::onSearchFailed( const QString& reason )
{
    _dialog->setBusy( false );
    emit errorOccurred( reason );
    sender()->deleteLater();
}

} // namespace PVE
