/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "vm-launcher-dialog-view.h"

#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QPushButton>

namespace {

const QString kVMNamePlaceholder = "vm name";
const QString kVMIDPlaceholder = "vmid";
const QString kOkButtonLabel = "Ok";
const QString kCancelButtonLabel = "Cancel";
const QString kCheckButtonLabel = "Check";
const QString kFullscreenLabel = "Full screen";

const QString kVmidLineEditValid = "QLineEdit{background:rgb(60,179,113);}";
const QString kVmidLineEditInValid = "QLineEdit{background:rgb(255,99,71);}";

} // namespace

namespace PVE {

VMLauncherDialogView::VMLauncherDialogView( QWidget* parent,
                                            Qt::WindowFlags flags )
    : QWidget( parent, flags ),
      _launcherNameLineEdit( new QLineEdit ),
      _vmidLineEdit( new QLineEdit ),
      _fullscreenCheckBox( new QCheckBox( kFullscreenLabel ) ),
      _progressBar( new QProgressBar )
{
    _launcherNameLineEdit->setPlaceholderText( kVMNamePlaceholder );
    _vmidLineEdit->setPlaceholderText( kVMIDPlaceholder );
    _progressBar->setRange( 0, 0 );
    _progressBar->setVisible( false );

    const auto okButton = new QPushButton( kOkButtonLabel );
    connect( okButton,
             &QPushButton::clicked,
             this,
             &VMLauncherDialogView::okButtonClicked );

    const auto cancelButton = new QPushButton( kCancelButtonLabel );
    connect( cancelButton,
             &QPushButton::clicked,
             this,
             &VMLauncherDialogView::cancelButtonClicked );

    const auto checkButton = new QPushButton( kCheckButtonLabel );
    connect( checkButton,
             &QPushButton::clicked,
             this,
             &VMLauncherDialogView::checkButtonClicked );

    const auto buttonsLayout = new QHBoxLayout;
    buttonsLayout->addWidget( checkButton );
    buttonsLayout->addStretch();
    buttonsLayout->addWidget( okButton );
    buttonsLayout->addWidget( cancelButton );

    const auto layout = new QVBoxLayout;
    layout->addWidget( _launcherNameLineEdit );
    layout->addWidget( _vmidLineEdit );
    layout->addWidget( _fullscreenCheckBox );
    layout->addWidget( _progressBar );
    layout->addLayout( buttonsLayout );

    setLayout( layout );
}

void VMLauncherDialogView::setVmidStatus( bool isValid )
{
    _vmidLineEdit->setStyleSheet( isValid ? kVmidLineEditValid
                                          : kVmidLineEditInValid );
}

} // namespace PVE
