/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "vm-launcher-dialog.h"

#include <QVBoxLayout>

namespace PVE {

VMLauncherDialog::VMLauncherDialog( QWidget* parent,
                                            Qt::WindowFlags flags )
    : QDialog( parent, flags ),
      _view( new VMLauncherDialogView )
{
    connect( _view,
             &VMLauncherDialogView::okButtonClicked,
             this,
             &VMLauncherDialog::onOkButtonClicked );

    connect( _view,
             &VMLauncherDialogView::cancelButtonClicked,
             this,
             &VMLauncherDialog::onCancelButtonClicked );

    connect( _view,
             &VMLauncherDialogView::checkButtonClicked,
             this,
             &VMLauncherDialog::onCheckButtonClicked );

    const auto layout = new QVBoxLayout;
    layout->addWidget( _view );

    setLayout( layout );
}

void VMLauncherDialog::onOkButtonClicked()
{
    emit accepted( _view->launcherName(),
                   _view->vmid().toInt(),
                   _view->fullscreen() );
    accept();
}

void VMLauncherDialog::onCancelButtonClicked()
{
    reject();
}

void VMLauncherDialog::onCheckButtonClicked()
{
    _view->setBusy( true );

    emit checkRequested( _view->launcherName(),
                         _view->vmid().toInt() );
}

} // namespace PVE
