/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "vm-launchers-view.h"

#include <QVBoxLayout>
#include <QLabel>
#include <QPushButton>
#include <QHeaderView>

namespace {

const QString kPageTitle = "Virtual Machines";
const QString kAddButtonLabel = "Add";
const QString kEditButtonLabel = "Edit";
const QString kRemoveButtonLabel = "Remove";
const QString kConnectButtonLabel = "Connect";

} // namespace

namespace PVE {

VMLaunchersView::VMLaunchersView( QWidget* parent,
                                  Qt::WindowFlags flags )
    : QWidget( parent, flags ),
      _tableView( new QTableView ),
      _progressBar( new QProgressBar )
{
    _tableView->setSelectionBehavior( QAbstractItemView::SelectRows );
    _tableView->setSelectionMode( QAbstractItemView::SingleSelection );

    const auto horizontalHeader = _tableView->horizontalHeader();
    horizontalHeader->setStretchLastSection( true );
    const auto verticalHeader = _tableView->verticalHeader();
    verticalHeader->setVisible( false );

    _progressBar->setVisible( false );
    _progressBar->setRange( 0, 0 );

    const auto addButton = new QPushButton( kAddButtonLabel );
    connect( addButton,
             &QPushButton::clicked,
             this,
             &VMLaunchersView::addButtonClicked );

    const auto editButton = new QPushButton( kEditButtonLabel );
    connect( editButton,
             &QPushButton::clicked,
             this,
             &VMLaunchersView::editButtonClicked );

    const auto removeButton = new QPushButton( kRemoveButtonLabel );
    connect( removeButton,
             &QPushButton::clicked,
             this,
             &VMLaunchersView::removeButtonClicked );

    const auto connectButton = new QPushButton( kConnectButtonLabel );
    connect( connectButton,
             &QPushButton::clicked,
             this,
             &VMLaunchersView::connectButtonClicked );

    const auto buttonsLayout = new QHBoxLayout;
    buttonsLayout->addWidget( addButton );
    buttonsLayout->addWidget( editButton );
    buttonsLayout->addWidget( removeButton );
    buttonsLayout->addStretch();
    buttonsLayout->addWidget( connectButton );

    connect( _tableView,
             &QTableView::activated,
             this,
             &VMLaunchersView::onTableActivated );

    const auto layout = new QVBoxLayout;
    layout->addWidget( new QLabel( kPageTitle ), 0, Qt::AlignHCenter );
    layout->addWidget( _tableView );
    layout->addWidget( _progressBar );
    layout->addLayout( buttonsLayout );

    setLayout( layout );
}

void VMLaunchersView::onTableActivated( const QModelIndex& index )
{
    emit launcherSelectedAtIndex( index.row() );
}

} // namespace PVE
