/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "keychain.h"

#include <qt5keychain/keychain.h>

#include <QApplication>
#include <QEventLoop>

#include "errors.h"

namespace {

const QString kKeyFormat = "%1@%2/password";

void setupJob( QKeychain::Job& job,
               const QString& username,
               const QString& serverURL )
{
    job.setInsecureFallback( false );
    job.setKey( QString( kKeyFormat ).arg( username ).arg( serverURL ) );
    job.setAutoDelete( false );
}

void executeJob( QKeychain::Job& job )
{
    QEventLoop loop;
    job.connect( &job, &QKeychain::Job::finished, &loop, &QEventLoop::quit );
    job.start();
    loop.exec();

    if( job.error() != QKeychain::Error::NoError )
    {
        throw PVE::KeychainException( job.errorString() );
    }
}

} // namespace

namespace PVE {
namespace SyncKeychain {

QString getUserPassword( const QString& username, const QString& serverURL )
{
    QKeychain::ReadPasswordJob job( QApplication::applicationName() );
    setupJob( job, username, serverURL );

    executeJob( job );

    return job.textData();
}

void setUserPassword( const QString& username,
                      const QString &serverURL,
                      const QString& password )
{
    QKeychain::WritePasswordJob job( QApplication::applicationName() );
    setupJob( job, username, serverURL );

    job.setTextData( password );

    executeJob( job );
}

} // namespace Keychain
} // namespace PVE
