/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "vm-launcher-appender.h"

#include "find-vm-command.h"

namespace {

const QString kVMNotFound = "Could not find virtual machine";

} // namespace

namespace PVE {

VMLauncherAppender::VMLauncherAppender( const QSharedPointer<Account>& account,
                    QObject* parent )
    : QObject( parent ),
      _account( account ),
      _newLauncherName(),
      _newLauncherArguments()
{
}

void VMLauncherAppender::append( int vmid,
                                 const QString& launcherName,
                                 const VMLaunchArguments& arguments )
{
    _newLauncherName = launcherName;
    _newLauncherArguments = arguments;

    const auto findVMCommand = new FindVMCommand( _account, vmid );

    connect( findVMCommand,
             &FindVMCommand::succeeded,
             this,
             &VMLauncherAppender::onSearchSucceeded );

    connect( findVMCommand,
             &FindVMCommand::failed,
             this,
             &VMLauncherAppender::onSearchFailed );

    findVMCommand->run();
}

void VMLauncherAppender::onSearchSucceeded()
{
    const auto command = qobject_cast<FindVMCommand*>( sender() );
    const auto vm = command->result();

    if( !vm )
    {
        emit errorOccurred( kVMNotFound );
        command->deleteLater();
        return;
    }

    const auto launcherName = _newLauncherName.isEmpty() ? vm->name()
                                                         : _newLauncherName;
    const auto launcher = QSharedPointer<VMLauncher>::create( launcherName,
                                                              vm->id(),
                                                              _newLauncherArguments );
    launcher->setCachedVM( vm );

    emit appended( launcher );

    command->deleteLater();
}

void VMLauncherAppender::onSearchFailed( const QString& reason )
{
    emit errorOccurred( reason );
    sender()->deleteLater();
}

} // namespace
