/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "vm-launcher-connector.h"

#include "connect-command.h"

namespace PVE {

VMLauncherConnector::VMLauncherConnector( const QSharedPointer<Account>& account,
                                          QObject* parent )
    : QObject( parent ),
      _account( account )
{
}

void VMLauncherConnector::connect( const QSharedPointer<VMLauncher>& launcher )
{
    if( !launcher->isValid() )
    {
        emit errorOccurred( "Could not connect to invalid virtual machine" );
        return;
    }

    const auto connectCommand = new ConnectCommand( _account,
                                                    launcher->vmid(),
                                                    launcher->arguments().fullscreen );
    QObject::connect( connectCommand,
                      &ConnectCommand::succeeded,
                      this,
                      &VMLauncherConnector::onConnected );

    QObject::connect( connectCommand,
                      &ConnectCommand::failed,
                      this,
                      &VMLauncherConnector::onConnectionFailed );

    connectCommand->run();
}

void VMLauncherConnector::onConnected()
{
    emit connected();
    sender()->deleteLater();
}

void VMLauncherConnector::onConnectionFailed( const QString& reason )
{
    emit errorOccurred( reason );
    sender()->deleteLater();
}

} // namespace PVE
