/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "vm-launcher-validator.h"

#include "find-vm-command.h"

namespace PVE {

VMLauncherValidator::VMLauncherValidator( const QSharedPointer<Account>& account,
                                          QObject* parent )
    : QObject( parent ),
      _account( account )
{
}

void VMLauncherValidator::validate( const QVector<QSharedPointer<VMLauncher>>& launchers )
{
    for( const auto& launcher : launchers )
    {
        if( !launcher->isValid() )
        {
            validate( launcher );
        }
    }
}

void VMLauncherValidator::validate( const QSharedPointer<VMLauncher>& launcher )
{
    const auto findVMCommand = new FindVMCommand( _account, launcher->vmid() );

    connect( findVMCommand,
             &FindVMCommand::succeeded,
             this,
             &VMLauncherValidator::onSearchSucceeded );

    connect( findVMCommand,
             &FindVMCommand::failed,
             this,
             &VMLauncherValidator::errorOccurred );

    findVMCommand->run();
}

void VMLauncherValidator::onSearchSucceeded()
{
    const auto command = qobject_cast<FindVMCommand*>( sender() );
    command->deleteLater();

    const auto vm = command->result();

    if( !vm )
    {
        return;
    }

    const auto vmid = vm->id();

    const auto& launchers = _account->launchers();

    for( const auto& launcher : launchers )
    {
        if( launcher->vmid() == vmid )
        {
            launcher->setCachedVM( vm );
            return;
        }
    }
}

void VMLauncherValidator::onSearchFailed( const QString& reason )
{
    emit errorOccurred( reason );
    sender()->deleteLater();
}

} // namespace PVE
