/*
This file is part of PVE Spice Client.

PVE Spice Client is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PVE Spice Client is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PVE Spice Client.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "vm-launcher.h"

namespace PVE {

bool operator ==( const VMLaunchArguments& lhs, const VMLaunchArguments& rhs )
{
    return lhs.fullscreen == rhs.fullscreen;
}

bool operator !=( const VMLaunchArguments& lhs, const VMLaunchArguments& rhs )
{
    return !( lhs == rhs );
}

VMLauncher::VMLauncher( const QString& name,
                        int vmid,
                        const VMLaunchArguments& arguments )
    : _name( name ),
      _vmid( vmid ),
      _arguments( arguments ),
      _cachedVM()
{
}

void VMLauncher::setName( const QString& name )
{
    if( _name != name )
    {
        _name = name;
        emit changed( this );
    }
}

void VMLauncher::setVmid( int vmid )
{
    if( _vmid != vmid )
    {
        _vmid = vmid;
        _cachedVM = Q_NULLPTR;

        emit changed( this );
    }
}

void VMLauncher::setArguments( const VMLaunchArguments& arguments )
{
    if( _arguments != arguments )
    {
        _arguments = arguments;
        emit changed( this );
    }
}

void VMLauncher::setCachedVM( const QSharedPointer<VirtualMachine>& vm )
{
    if( _cachedVM != vm )
    {
        _cachedVM = vm;

        connect( _cachedVM.data(),
                 &VirtualMachine::changed,
                 this,
                 &VMLauncher::onCachedVMChanged );

        emit changed( this );
    }
}

void VMLauncher::onCachedVMChanged( VirtualMachine* /*vm*/ )
{
    emit changed( this );
}

} // namespace PVE
